summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--tools/llvm-bcanalyzer/Makefile (renamed from tools/llvm-abcd/Makefile)4
-rw-r--r--tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp (renamed from tools/llvm-abcd/llvm-abcd.cpp)10
2 files changed, 7 insertions, 7 deletions
diff --git a/tools/llvm-abcd/Makefile b/tools/llvm-bcanalyzer/Makefile
index 1c2a9dc881..2608344f38 100644
--- a/tools/llvm-abcd/Makefile
+++ b/tools/llvm-bcanalyzer/Makefile
@@ -1,4 +1,4 @@
-##===- tools/llvm-abcd/Makefile ----------------------------*- Makefile -*-===##
+##===- tools/llvm-bcanalyzer/Makefile ----------------------*- Makefile -*-===##
#
# The LLVM Compiler Infrastructure
#
@@ -8,6 +8,6 @@
##===----------------------------------------------------------------------===##
LEVEL = ../..
-TOOLNAME = llvm-abcd
+TOOLNAME = llvm-bcanalyzer
USEDLIBS = bcreader vmcore support.a
include $(LEVEL)/Makefile.common
diff --git a/tools/llvm-abcd/llvm-abcd.cpp b/tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp
index 820de7fe80..d0ba73d2dc 100644
--- a/tools/llvm-abcd/llvm-abcd.cpp
+++ b/tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp
@@ -1,4 +1,4 @@
//===-- llvm-abcd.cpp - Analysis of Byte Code Dumper ----------------------===//
//
// The LLVM Compiler Infrastructure
//
@@ -8,8 +8,8 @@
//===----------------------------------------------------------------------===//
//
// This tool may be invoked in the following manner:
// llvm-abcd [options] - Read LLVM bytecode from stdin
// llvm-abcd [options] x.bc - Read LLVM bytecode from the x.bc file
//
// Options:
// --help - Output information about command line switches
@@ -49,7 +49,7 @@ int
main(int argc, char **argv)
{
cl::ParseCommandLineOptions(argc, argv,
- " llvm-abcd Analysis of ByteCode Dumper\n");
+ " llvm-bcanalyzer Analysis of ByteCode Dumper\n");
PrintStackTraceOnErrorSignal();
@@ -66,7 +66,7 @@ main(int argc, char **argv)
/// Analyze the bytecode file
Module* M = AnalyzeBytecodeFile(InputFilename, bca, &ErrorMessage);
// All that abcd does is write the gathered statistics to the output
PrintBytecodeAnalysis(bca,*Out);
if ( M && Verify ) {
@@ -1,4 +1,4 @@
-//===-- llvm-abcd.cpp - Analysis of Byte Code Dumper ----------------------===//
+//===-- llvm-bcanalyzer.cpp - Byte Code Analyzer --------------------------===//
//
// The LLVM Compiler Infrastructure
@@ -8,8 +8,8 @@
//
// This tool may be invoked in the following manner:
-// llvm-abcd [options] - Read LLVM bytecode from stdin
-// llvm-abcd [options] x.bc - Read LLVM bytecode from the x.bc file
+// llvm-bcanalyzer [options] - Read LLVM bytecode from stdin
+// llvm-bcanalyzer [options] x.bc - Read LLVM bytecode from the x.bc file
//
// Options:
@@ -66,7 +66,7 @@ main(int argc, char **argv)
/// Analyze the bytecode file
Module* M = AnalyzeBytecodeFile(InputFilename, bca, &ErrorMessage);
- // All that abcd does is write the gathered statistics to the output
+ // All that bcanalyzer does is write the gathered statistics to the output
PrintBytecodeAnalysis(bca,*Out);
if ( M && Verify ) {